// 
// written by Stefan Weinzierl
//

#include <iostream>
#include <stdexcept>
#include <ctime>

#include "partonevolution/partonevolution.h"

using namespace std;
using namespace pdf;

void check2(partondistribution u, partondistribution d, partondistribution s, partondistribution g, partondistribution q, double Q, double x, int n_points);

int main()
{

  try{

    alpha_strong::method = alpha_strong::truncate_in_one_over_L;

    alpha_strong::charm_threshold  = 0.0;
    alpha_strong::bottom_threshold = 1E10;

    alpha_strong::lambda_3 = 0.250;
    alpha_strong::lambda_4 = 0.250;
    alpha_strong::lambda_5 = 0.250;


    double iniscale = 2.0;

    // ------------------------------------------------------------------------

    // u- valence
    double A_u[1]     = { 35/16.};
    double alpha_u[1] = { 0.5 };
    double beta_u[1]  = { 3.0 };

    partondistribution uvalence =
      partondistribution(1,iniscale,A_u,alpha_u,beta_u,-1);

    // -----------------------------------------------------------------
    // d-valence
    double A_d[1]     = { 315/256.};
    double alpha_d[1] = { 0.5 };
    double beta_d[1]  = { 4.0 };

    partondistribution dvalence =
      partondistribution(1,iniscale,A_d,alpha_d,beta_d,-1);

    // -----------------------------------------------------------------
    // gluon distribution
    double A_g[1]     = { 1.90836};
    double alpha_g[1] = { -0.2 };
    double beta_g[1]  = { 5.0 };

    partondistribution gluondistr =
      partondistribution(1,iniscale,A_g,alpha_g,beta_g);

    // ------------------------------------------------------------------
    // quark-singlet combination
    double A_sing[3]     = { 0.673345, 35/16., 315/256.};
    double alpha_sing[3] = { -0.2,     0.5,    0.5 };
    double beta_sing[3]  = {  7.0,     3.0,    4.0 };

    partondistribution sigmadistr =
      partondistribution(3,iniscale,A_sing,alpha_sing,beta_sing);

    // ------------------------------------------------------------------
    // non-singlet u+ubar+d+dabar+s+sbar - 3 ( c + cbar)

    partondistribution quark_nonsinglet =
      partondistribution(3,iniscale,A_sing,alpha_sing,beta_sing);

    // ------------------------------------------------------------------
    // evolution

    double Q = 10.0;
    double x = 0.1;

    evolutionkernel::method = evolutionkernel::N_space;
    cout << endl;
    cout << " timing for the N-space method : " << endl; 
    cout << endl;
    check2(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,5);

    evolutionkernel::method = evolutionkernel::x_space_truncate_in_one_over_L;
    cout << endl;
    cout << " timing for the x-space method : " << endl; 
    cout << endl;
    check2(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,5);

    // --------------------------------------------------------------

  } catch (std::exception &e)
    {
      cout << "Exception : " << e.what() << endl;
    }

  return 0;
}

  void check2(partondistribution u, partondistribution d, partondistribution s, partondistribution g, partondistribution q_ns, double QQ, double x, int n_points)
    {
      time_t time_start;
      time_t time_end;

      int nmax = 100;

      // measuring time starts here
      time(&time_start);

      for (int i=0; i<nmax; i++)
	{
	  // avoid loop unrolling
	  double Q = QQ + i/((double) nmax);
	  evolve_nonsinglet(u,Q,x,n_points);
	}

      // measuring time end here
      time(&time_end);

      cout << nmax << " evolutions of a non-singlet pdf with a quadrature formula of " << n_points << " points take " << difftime(time_end,time_start) << " seconds." << endl;
      cout << endl;


      // measuring time starts here
      time(&time_start);

      for (int i=0; i<nmax; i++)
	{
	  // avoid loop unrolling
	  double Q = QQ + i/((double) nmax);
	  evolve_singlet(s,g,Q,x,n_points);
	}

      // measuring time end here
      time(&time_end);

      cout << nmax << " evolutions in the singlet case with a quadrature formula of " << n_points << " points take " << difftime(time_end,time_start) << " seconds." << endl;
      cout << endl;



    }

