// 
// written by Stefan Weinzierl
//

#include <iostream>
#include <stdexcept>

#include "partonevolution/partonevolution.h"

using namespace std;
using namespace pdf;

void check1(partondistribution u, partondistribution d, partondistribution s, partondistribution g, partondistribution q, double Q, double x, int n_points);

int main()
{

  try{

    alpha_strong::method = alpha_strong::truncate_in_one_over_L;

    alpha_strong::charm_threshold  = 0.0;
    alpha_strong::bottom_threshold = 1E10;

    alpha_strong::lambda_3 = 0.250;
    alpha_strong::lambda_4 = 0.250;
    alpha_strong::lambda_5 = 0.250;


    double iniscale = 2.0;

    // ------------------------------------------------------------------------

    // u- valence
    double A_u[1]     = { 35/16.};
    double alpha_u[1] = { 0.5 };
    double beta_u[1]  = { 3.0 };

    partondistribution uvalence =
      partondistribution(1,iniscale,A_u,alpha_u,beta_u,-1);

    // -----------------------------------------------------------------
    // d-valence
    double A_d[1]     = { 315/256.};
    double alpha_d[1] = { 0.5 };
    double beta_d[1]  = { 4.0 };

    partondistribution dvalence =
      partondistribution(1,iniscale,A_d,alpha_d,beta_d,-1);

    // -----------------------------------------------------------------
    // gluon distribution
    double A_g[1]     = { 1.90836};
    double alpha_g[1] = { -0.2 };
    double beta_g[1]  = { 5.0 };

    partondistribution gluondistr =
      partondistribution(1,iniscale,A_g,alpha_g,beta_g);

    // ------------------------------------------------------------------
    // quark-singlet combination
    double A_sing[3]     = { 0.673345, 35/16., 315/256.};
    double alpha_sing[3] = { -0.2,     0.5,    0.5 };
    double beta_sing[3]  = {  7.0,     3.0,    4.0 };

    partondistribution sigmadistr =
      partondistribution(3,iniscale,A_sing,alpha_sing,beta_sing);

    // ------------------------------------------------------------------
    // non-singlet u+ubar+d+dabar+s+sbar - 3 ( c + cbar)

    partondistribution quark_nonsinglet =
      partondistribution(3,iniscale,A_sing,alpha_sing,beta_sing);

    // ------------------------------------------------------------------
    // evolution

    double Q = 10.0;
    double x;

    evolutionkernel::method = evolutionkernel::N_space;
    cout << endl;
    cout << "checking the lower part of table 1 of hep-ph/9609400 " << endl;
    cout << " ( N - space method ) " << endl; 
    cout << endl;

    x = 0.00001;
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,3);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,5);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,10);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,20);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,30);
    cout << endl;

    x = 0.0001;
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,3);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,5);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,10);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,20);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,30);
    cout << endl;

    x = 0.001;
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,3);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,5);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,10);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,20);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,30);
    cout << endl;

    x = 0.01;
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,3);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,5);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,10);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,20);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,30);
    cout << endl;

    x = 0.1;
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,3);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,5);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,10);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,20);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,30);
    cout << endl;

    x = 0.3;
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,3);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,5);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,10);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,20);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,30);
    cout << endl;

    x = 0.7;
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,3);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,5);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,10);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,20);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,30);
    cout << endl;

    evolutionkernel::method = evolutionkernel::x_space_truncate_in_one_over_L;
    cout << endl;
    cout << "checking the upper part of table 1 of hep-ph/9609400 " << endl;
    cout << " ( x - space method, this is less efficient ) " << endl; 
    cout << endl;

    x = 0.00001;
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,3);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,5);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,10);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,20);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,30);
    cout << endl;

    x = 0.0001;
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,3);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,5);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,10);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,20);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,30);
    cout << endl;

    x = 0.001;
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,3);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,5);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,10);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,20);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,30);
    cout << endl;

    x = 0.01;
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,3);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,5);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,10);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,20);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,30);
    cout << endl;

    x = 0.1;
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,3);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,5);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,10);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,20);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,30);
    cout << endl;

    x = 0.3;
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,3);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,5);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,10);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,20);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,30);
    cout << endl;

    x = 0.7;
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,3);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,5);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,10);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,20);
    check1(uvalence,dvalence,sigmadistr,gluondistr,quark_nonsinglet,Q,x,30);
    cout << endl;

    // --------------------------------------------------------------

  } catch (std::exception &e)
    {
      cout << "Exception : " << e.what() << endl;
    }

  return 0;
}



  void check1(partondistribution u, partondistribution d, partondistribution s, partondistribution g, partondistribution q_ns, double Q, double x, int n_points)
    {
      double u_v,d_v,quark_ns;
      double Sigma,gluon,Sea,c;
      vector_d singlet(2);

      u_v = evolve_nonsinglet(u,Q,x,n_points);
      d_v = evolve_nonsinglet(d,Q,x,n_points);
      singlet    = evolve_singlet(s,g,Q,x,n_points);
      quark_ns = evolve_nonsinglet(q_ns,Q,x,n_points);

      Sigma = singlet[0];
      gluon = singlet[1];

      Sea = Sigma - u_v - d_v;

      c = ( Sigma - quark_ns ) / 8.0;

      cout << " N = " << n_points 
	   << ", x = " << x 
	   << ", x u_v = " << x*u_v 
	   << ", x d_v = " << x*d_v 
	   << ", x S = " << x*Sea 
	   << ", 2 x c = " << 2*x*c 
	   << ", x g = " << x*gluon << endl;
    }

