
/** @file Gauss_Laguerre.h
 *
 * Interface to Gauss_Laguerre
 *
 */

/*
 *  Copyright (C) 2002 Stefan Weinzierl
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __PDF_GAUSS_LAGUERRE_H__
#define __PDF_GAUSS_LAGUERRE_H__

#include "matrix_d.h"

#include "partondistribution.h"

namespace pdf {

  double evolve_nonsinglet(const partondistribution & f, double Q, double x, int number_of_points = 5);
  double evolve_nonsinglet_3(const partondistribution & f, double Q, double x);
  double evolve_nonsinglet_5(const partondistribution & f, double Q, double x);
  double evolve_nonsinglet_10(const partondistribution & f, double Q, double x);
  double evolve_nonsinglet_20(const partondistribution & f, double Q, double x);
  double evolve_nonsinglet_30(const partondistribution & f, double Q, double x);

  vector_d evolve_singlet(const partondistribution & s, const partondistribution & g, double Q, double x, int number_of_points = 5);
  vector_d evolve_singlet_3(const partondistribution & s, const partondistribution & g, double Q, double x);
  vector_d evolve_singlet_5(const partondistribution & s, const partondistribution & g, double Q, double x);
  vector_d evolve_singlet_10(const partondistribution & s, const partondistribution & g, double Q, double x);
  vector_d evolve_singlet_20(const partondistribution & s, const partondistribution & g, double Q, double x);
  vector_d evolve_singlet_30(const partondistribution & s, const partondistribution & g, double Q, double x);

  vector_d evolve_singlet_with_qed(const partondistribution & Delta, 
				   const partondistribution & s, const partondistribution & g, 
				   const partondistribution & phot, const partondistribution & lept, 
				   double Q, double x, int number_of_points = 5);
  vector_d evolve_singlet_with_qed_3(const partondistribution & Delta, 
				     const partondistribution & s, const partondistribution & g, 
				     const partondistribution & phot, const partondistribution & lept, 
				     double Q, double x);
  vector_d evolve_singlet_with_qed_5(const partondistribution & Delta, 
				     const partondistribution & s, const partondistribution & g, 
				     const partondistribution & phot, const partondistribution & lept, 
				     double Q, double x);
  vector_d evolve_singlet_with_qed_10(const partondistribution & Delta, 
				      const partondistribution & s, const partondistribution & g, 
				      const partondistribution & phot, const partondistribution & lept, 
				      double Q, double x);
  vector_d evolve_singlet_with_qed_20(const partondistribution & Delta, 
				      const partondistribution & s, const partondistribution & g, 
				      const partondistribution & phot, const partondistribution & lept, 
				      double Q, double x);
  vector_d evolve_singlet_with_qed_30(const partondistribution & Delta, 
				      const partondistribution & s, const partondistribution & g, 
				      const partondistribution & phot, const partondistribution & lept, 
				      double Q, double x);

} // namespace pdf

#endif // ndef __PDF_GAUSS_LAGUERRE_H__

