
/** @file constants_math.h
 *
 * Interface to constants_math
 *
 */

/*
 *  Copyright (C) 2002 Stefan Weinzierl
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __PDF_CONSTANTS_MATH_H__
#define __PDF_CONSTANTS_MATH_H__

#include <cmath>

namespace pdf {

  const double Pi = 3.14159265358979;
  const double Euler = 0.577215664901533;
  const double zeta2 = pow(Pi,2)/6.0;
  const double zeta3 = 1.20205690315959;

  // --------------------------------------
  // constants for SU(3)

  const double Nc = 3.0;
  const double CF = 4.0/3.0;
  const double TR = 0.5;
  const double CA = 3.0;

  // electromagnetic charges in units of the (negative) electron charge

  const double Q_up       = -2.0/3.0;
  const double Q_down     =  1.0/3.0;

  const double Q_electron =  1.0;

} // namespace pdf

#endif // ndef __PDF_CONSTANTS_MATH_H__

