
/** @file coupling_qed.h
 *
 * Interface to coupling_qed 
 *
 */

/*
 *  Copyright (C) 2002 Stefan Weinzierl
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __PARTICLE_SCATTERING_COUPLING_QED_H__
#define __PARTICLE_SCATTERING_COUPLING_QED_H__

namespace pdf {

  /**
   *
   * The electromagnetic constant.
   *
   * The class works with the quantity 
   *  \f[
   *     a = \frac{\alpha}{4\pi}.
   *  \f]
   * 
   * The value of \f$a\f$
   * is given by 
   * \f[
   *     a(Q^2) = a(Q_0^2) \frac{1}{ 1 + a(Q_0^2) \beta_0 L } .
   * \f]
   * where \f$ L = \ln \frac{Q^2}{Q_0^2}\f$.
   *
   */
  class alpha_finestruc {

    // ctors

    // static functions
    public :
      static double beta_0(int Nf_down, int Nf_up, int Nl);

      static int get_active_flavours(double Q);
      static int get_active_leptons(double Q);
      static double get_value(double Q, int Nf_down, int Nf_up, int Nl);

    // data members
    public :
      static double value_at_charm;
      static double value_at_tau;
      static double value_at_bottom;

      static double charm_threshold;
      static double tau_threshold;
      static double bottom_threshold;

  };

} // namespace pdf

#endif // ndef __PARTICLE_SCATTERING_COUPLING_QED_H__

