
/** @file evolutionkernel.h
 *
 * Interface to evolutionkernel
 *
 */

/*
 *  Copyright (C) 2002 Stefan Weinzierl
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __PDF_EVOLUTIONKERNEL_H__
#define __PDF_EVOLUTIONKERNEL_H__

#include "complex_d.h"
#include "matrix_c.h"

namespace pdf {

  /**
   *
   * This class implements the evolution kernels for
   * parton distributions.
   *
   */
  class evolutionkernel {

    // ctors

    // static functions
    public :
      static complex_d nonsinglet(const complex_d & z, double Q1, double Q0, int eta);
      static matrix_c  singlet(const complex_d & z, double Q1, double Q0);

      static complex_d nonsinglet_fixed_flavour(const complex_d & z, double Q1, double Q0, int Nf, int eta);
      static matrix_c  singlet_fixed_flavour(const complex_d & z, double Q1, double Q0, int Nf);

      // with qed effects
      static complex_d nonsinglet_with_qed(const complex_d & z, double Q1, double Q0, int eta, double electric_charge);
      static matrix_c  singlet_with_qed(const complex_d & z, double Q1, double Q0, int flag_qed = 1);

      static complex_d nonsinglet_with_qed_fixed_flavour(const complex_d & z, double Q1, double Q0, 
							 int Nf_down, int Nf_up, int Nl, 
							 int eta, double electric_charge);
      static matrix_c  singlet_with_qed_fixed_flavour(const complex_d & z, double Q1, double Q0, 
						      int Nf_down, int Nf_up, int Nl, int flag_qed = 1);

    // data members
      static int method;

      static int number_of_iterations;

    // keywords
      enum {
	N_space,
	x_space,
	x_space_truncate_in_one_over_L
      };

  };

} // namespace pdf

#endif // ndef __PDF_EVOLUTIONKERNEL_H__

