
/** @file integration_contour.h
 *
 * Interface to integration_contour
 *
 */

/*
 *  Copyright (C) 2002 Stefan Weinzierl
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __PDF_INTEGRATION_CONTOUR_H__
#define __PDF_INTEGRATION_CONTOUR_H__

#include "complex_d.h"
#include "matrix_c.h"
#include "matrix_d.h"

#include "partondistribution.h"

namespace pdf {

  /**
   *
   * This class provides some helper methods to perform
   * numerically an inverse Mellin transform along a parabolic contour.
   *
   */
  class integration_contour {

    // ctors

    // static functions
    public :
      static double nonsinglet(const partondistribution & f, double Q, double x, double u);
      static vector_d singlet(const partondistribution & s, const partondistribution & g, double Q, double x, double u);

      static vector_d singlet_with_qed(const partondistribution & Delta, 
				       const partondistribution & s, const partondistribution & g, 
				       const partondistribution & phot, const partondistribution & lept, 
				       double Q, double x, double u);

    // data members

  };

} // namespace pdf

#endif // ndef __PDF_INTEGRATION_CONTOUR_H__

