
/** @file partonevolution.h
 *
 * Top level include file for the library.
 * This file should be included by all applications using the library.
 *
 */

/*
 *  Copyright (C) 2001 Stefan Weinzierl
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


/** \mainpage Fast Evolution of Parton Distributions
 *
 * \subsection title Partonevolution library
 * \author Stefan Weinzierl
 * \version 1.1.4
 *
 * The partonevolution library can be used to evolve parton distributions
 * given by parameterizations at a scale \f$Q_0\f$ to the desired scale \f$Q\f$
 * according to next-to-leading order evolution kernels.
 *
 * The library is described in :
 * S. Weinzierl, "Fast evolution of parton distributions",
 *  http://arXiv.org/abs/hep-ph/0203112
 *
 * The partonevolution library can be downloaded from
 *  http://particlephysics.uni-mainz.de/weinzierl/download/partonevolution-1.1.4.tar.gz
 *
 * The program uses the Mellin transform method with an optimized contour.
 * Due to this optimized contour the program needs only a few
 * evaluations of the anomalous dimensions and is therefore extremely fast.
 * The library is therefore suited to be used in analysis involving parton
 * distributions with errors, where a functional integration over a set of
 * pdf's is needed.
 * In addition, the program can also be used to simulate x-space evolution programs.
 *
 * From version 1.1.0 onwards, the library includes an option to include leading-order
 * QED corrections to the evolution of parton distributions.
 * The formalism is described in :
 * M. Roth and S. Weinzierl, "QED corrections to the evolution of parton distributions",
 *  http://arXiv.org/abs/hep-ph/0403200
 * (At the moment, no speed-improved QED kernels are implemented and the evolution with
 * QED corrections is rather slow.)
 *
 * Documentation of the library is inserted as comment lines inside the source
 * code and can be extracted with the help of the documentation system "doxygen".
 * Doxygen is available from
 *  http://www.stack.nl/~dimitri/doxygen
 *
 * When the library is used for scientific work that leads to publication in a 
 * scientific journal, please refer to this program as :
 *  S. Weinzierl, "Fast evolution of parton distributions", 
 *  Comp. Phys. Comm. 148, (2002), 314, (hep-ph/0203112).
 *
 */ 

/** \namespace pdf
 *
 * All classes and functions of the partonevolution package are defined
 * in the namespace pdf.
 *
 */

#ifndef __PDF_PDF_H__
#define __PDF_PDF_H__

#include "constants_math.h"
#include "complex_d.h"
#include "matrix_template.h"
#include "matrix_d.h"
#include "matrix_c.h"
#include "special_functions.h"

#include "partondistribution.h"
#include "coupling.h"
#include "coupling_qed.h"
#include "anomalous.h"
#include "integration_contour.h"
#include "evolutionkernel.h"
#include "Gauss_Laguerre.h"

#endif // ndef __PDF_PDF_H__


