
/** @file special_functions.h
 *
 * Interface to special_functions
 *
 */

/*
 *  Copyright (C) 2002 Stefan Weinzierl
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __PDF_SPECIAL_FUNCTIONS_H__
#define __PDF_SPECIAL_FUNCTIONS_H__

#include "complex_d.h"

namespace pdf {

  complex_d cot(const complex_d & xx);
  complex_d LogSin(const complex_d & xx);
  complex_d Gamma(const complex_d & xx);
  complex_d LogGamma(const complex_d & xx);
  complex_d Beta(const complex_d & x, const complex_d & y);
  double cot(double xx);
  double LogSin(double xx);
  double Gamma(double xx);
  double LogGamma(double xx);
  double Beta(double x, double y);

  complex_d IncompleteGamma(const complex_d & a, double x);
  complex_d HyperGeometric(const complex_d & a, const complex_d & b, const complex_d & c, const complex_d & z);

  complex_d Psi(const complex_d & z);
  complex_d Psi1(const complex_d & z);
  complex_d Psi2(const complex_d & z);
  complex_d Psi3(const complex_d & z);
  double Psi(double z);
  double Psi1(double z);
  double Psi2(double z);
  double Psi3(double z);

  complex_d S1(const complex_d & z);
  complex_d S2(const complex_d & z);
  complex_d S3(const complex_d & z);
  complex_d Stilde(const complex_d & z, int eta);
  complex_d Sprim1(const complex_d & z, int eta);
  complex_d Sprim2(const complex_d & z, int eta);
  complex_d Sprim3(const complex_d & z, int eta);

  complex_d M1_helper(const complex_d & z);
  complex_d M2_helper(const complex_d & z);

} // namespace pdf

#endif // ndef __PDF_SPECIAL_FUNCTIONS_H__



